/*
 * This file is a part of Winix
 * and is not publicly distributed
 * 
 * Copyright (c) 2010-2012, Tomasz Sowa
 * All rights reserved.
 * 
 */
 
#ifndef headerfile_winix_plugins_ticket_sessiondata
#define headerfile_winix_plugins_ticket_sessiondata

#include <vector>
#include <string>
#include <map>
#include "core/plugindata.h"
#include "ticket.h"
#include "functions/rm.h"
#include "confparser/space.h"


namespace Ticket
{


struct SessionData : public PluginDataBase
{
	SessionData();
	~SessionData();


	typedef std::map<long, Ticket>    TicketMap;
	typedef std::map<long, PT::Space> SpaceMap;


	// temporary tickets for 'createticket' function
	// <parent_dir_id, Ticket>
	TicketMap create_ticket_map;

	// temporary tickets for 'editticket' function
	// <file_id, Ticket>
	TicketMap edit_ticket_map;


	// temporary spaces for 'createticket' function
	// these files should be deleted if a user will not click on the submit button
	SpaceMap create_space_map;

	// temporary spaces for 'editticket' function
	// these files should be deleted if a user will not click on the submit button
	SpaceMap edit_space_map;


	// inserting and returning a new ticket or just returning the ticket if it exists
	Ticket & GetTicket(long id, TicketMap & ticket_map, bool * is_new = 0);

	// inserting and returning a new space or just returning the space if it exists
	PT::Space & GetSpace(long id, SpaceMap & space_map, bool * is_new = 0);

	// for deleting files
	// !! IMPROVE ME: when the program exits there can be a situation that
	// fun_rm was finished and then an object of this class exits and call fun_rm
	// so we should guarantee that all sessions object are removed first
	Fun::Rm * fun_rm;

	void RemoveFiles(SpaceMap & space_map);


private:

	void RemoveFiles(PT::Space & space);

};


} // namespace


#endif
